## dbt-tests-adapter 1.15.0 - May 02, 2025

### Features

- Add base test case for sample mode ([#878](https://github.com/dbt-labs/dbt-adapters/issues/878))
- Add tests for `empty` and `sample` modes against python models ([#906](https://github.com/dbt-labs/dbt-adapters/issues/906))

### Fixes

- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))
